]> sigrok.org Git - libsigrok.git/blobdiff - sigrok.h
Change all sigrok_ prefixes to sr_.
[libsigrok.git] / sigrok.h
index a2d707ac7f3b9ab88bd5e21b99caa45f7529818c..c25380af7ba8cc108484a679f4fe637089497020 100644 (file)
--- a/sigrok.h
+++ b/sigrok.h
@@ -129,35 +129,35 @@ struct analog_sample {
        struct analog_probe probes[];
 };
 
-struct input {
-       struct input_format *format;
+struct sr_input {
+       struct sr_input_format *format;
        char *param;
        struct device *vdevice;
 };
 
-struct input_format {
+struct sr_input_format {
        char *extension;
        char *description;
        int (*format_match) (const char *filename);
-       int (*init) (struct input *in);
-       int (*loadfile) (struct input *in, const char *filename);
+       int (*init) (struct sr_input *in);
+       int (*loadfile) (struct sr_input *in, const char *filename);
 };
 
-struct output {
-       struct output_format *format;
+struct sr_output {
+       struct sr_output_format *format;
        struct device *device;
        char *param;
        void *internal;
 };
 
-struct output_format {
+struct sr_output_format {
        char *extension;
        char *description;
        int df_type;
-       int (*init) (struct output *o);
-       int (*data) (struct output *o, char *data_in, uint64_t length_in,
+       int (*init) (struct sr_output *o);
+       int (*data) (struct sr_output *o, char *data_in, uint64_t length_in,
                     char **data_out, uint64_t *length_out);
-       int (*event) (struct output *o, int event_type, char **data_out,
+       int (*event) (struct sr_output *o, int event_type, char **data_out,
                      uint64_t *length_out);
 };
 
@@ -237,7 +237,7 @@ struct hwcap_option {
        char *shortname;
 };
 
-struct sigrok_device_instance {
+struct sr_device_instance {
        int index;
        int status;
        int instance_type;
@@ -251,7 +251,7 @@ struct sigrok_device_instance {
        };
 };
 
-/* sigrok_device_instance types */
+/* sr_device_instance types */
 enum {
        USB_INSTANCE,
        SERIAL_INSTANCE,
@@ -286,7 +286,7 @@ enum {
 
 /* Device info IDs */
 enum {
/* struct sigrok_device_instance for this specific device */
        DI_INSTANCE,
        /* The number of probes connected to this device */
        DI_NUM_PROBES,
@@ -286,7 +286,7 @@ enum {
 /* Device info IDs */
 enum {
-       /* struct sigrok_device_instance for this specific device */
+       /* struct sr_device_instance for this specific device */
        DI_INSTANCE,
        /* The number of probes connected to this device */